@@ -44,7 +44,8 @@ pub struct ml_kem_512_ciphertext {
 
 #[no_mangle]
 pub extern "C" fn ml_kem_512_keygen(
-    encaps_out: Option<&mut ml_kem_512_encaps_key>, decaps_out: Option<&mut ml_kem_512_decaps_key>,
+    encaps_out: Option<&mut ml_kem_512_encaps_key>,
+    decaps_out: Option<&mut ml_kem_512_decaps_key>,
 ) -> u8 {
     use fips203::traits::{KeyGen, SerDes};
 
@@ -62,7 +63,8 @@ pub extern "C" fn ml_kem_512_keygen(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_512_keygen_from_seed(
-    seed: Option<&ml_kem_seed>, encaps_out: Option<&mut ml_kem_512_encaps_key>,
+    seed: Option<&ml_kem_seed>,
+    encaps_out: Option<&mut ml_kem_512_encaps_key>,
     decaps_out: Option<&mut ml_kem_512_decaps_key>,
 ) -> u8 {
     use fips203::traits::{KeyGen, SerDes};
@@ -82,7 +84,8 @@ pub extern "C" fn ml_kem_512_keygen_from_seed(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_512_encaps(
-    encaps: Option<&ml_kem_512_encaps_key>, ciphertext_out: Option<&mut ml_kem_512_ciphertext>,
+    encaps: Option<&ml_kem_512_encaps_key>,
+    ciphertext_out: Option<&mut ml_kem_512_ciphertext>,
     shared_secret_out: Option<&mut ml_kem_shared_secret>,
 ) -> u8 {
     use fips203::traits::{Encaps, SerDes};
@@ -106,7 +109,8 @@ pub extern "C" fn ml_kem_512_encaps(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_512_decaps(
-    decaps: Option<&ml_kem_512_decaps_key>, ciphertext: Option<&ml_kem_512_ciphertext>,
+    decaps: Option<&ml_kem_512_decaps_key>,
+    ciphertext: Option<&ml_kem_512_ciphertext>,
     shared_secret_out: Option<&mut ml_kem_shared_secret>,
 ) -> u8 {
     use fips203::traits::{Decaps, SerDes};
@@ -147,7 +151,8 @@ pub struct ml_kem_768_ciphertext {
 
 #[no_mangle]
 pub extern "C" fn ml_kem_768_keygen(
-    encaps_out: Option<&mut ml_kem_768_encaps_key>, decaps_out: Option<&mut ml_kem_768_decaps_key>,
+    encaps_out: Option<&mut ml_kem_768_encaps_key>,
+    decaps_out: Option<&mut ml_kem_768_decaps_key>,
 ) -> u8 {
     use fips203::traits::{KeyGen, SerDes};
 
@@ -165,7 +170,8 @@ pub extern "C" fn ml_kem_768_keygen(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_768_keygen_from_seed(
-    seed: Option<&ml_kem_seed>, encaps_out: Option<&mut ml_kem_768_encaps_key>,
+    seed: Option<&ml_kem_seed>,
+    encaps_out: Option<&mut ml_kem_768_encaps_key>,
     decaps_out: Option<&mut ml_kem_768_decaps_key>,
 ) -> u8 {
     use fips203::traits::{KeyGen, SerDes};
@@ -185,7 +191,8 @@ pub extern "C" fn ml_kem_768_keygen_from_seed(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_768_encaps(
-    encaps: Option<&ml_kem_768_encaps_key>, ciphertext_out: Option<&mut ml_kem_768_ciphertext>,
+    encaps: Option<&ml_kem_768_encaps_key>,
+    ciphertext_out: Option<&mut ml_kem_768_ciphertext>,
     shared_secret_out: Option<&mut ml_kem_shared_secret>,
 ) -> u8 {
     use fips203::traits::{Encaps, SerDes};
@@ -209,7 +216,8 @@ pub extern "C" fn ml_kem_768_encaps(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_768_decaps(
-    decaps: Option<&ml_kem_768_decaps_key>, ciphertext: Option<&ml_kem_768_ciphertext>,
+    decaps: Option<&ml_kem_768_decaps_key>,
+    ciphertext: Option<&ml_kem_768_ciphertext>,
     shared_secret_out: Option<&mut ml_kem_shared_secret>,
 ) -> u8 {
     use fips203::traits::{Decaps, SerDes};
@@ -269,7 +277,8 @@ pub extern "C" fn ml_kem_1024_keygen(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_1024_keygen_from_seed(
-    seed: Option<&ml_kem_seed>, encaps_out: Option<&mut ml_kem_1024_encaps_key>,
+    seed: Option<&ml_kem_seed>,
+    encaps_out: Option<&mut ml_kem_1024_encaps_key>,
     decaps_out: Option<&mut ml_kem_1024_decaps_key>,
 ) -> u8 {
     use fips203::traits::{KeyGen, SerDes};
@@ -289,7 +298,8 @@ pub extern "C" fn ml_kem_1024_keygen_from_seed(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_1024_encaps(
-    encaps: Option<&ml_kem_1024_encaps_key>, ciphertext_out: Option<&mut ml_kem_1024_ciphertext>,
+    encaps: Option<&ml_kem_1024_encaps_key>,
+    ciphertext_out: Option<&mut ml_kem_1024_ciphertext>,
     shared_secret_out: Option<&mut ml_kem_shared_secret>,
 ) -> u8 {
     use fips203::traits::{Encaps, SerDes};
@@ -313,7 +323,8 @@ pub extern "C" fn ml_kem_1024_encaps(
 
 #[no_mangle]
 pub extern "C" fn ml_kem_1024_decaps(
-    decaps: Option<&ml_kem_1024_decaps_key>, ciphertext: Option<&ml_kem_1024_ciphertext>,
+    decaps: Option<&ml_kem_1024_decaps_key>,
+    ciphertext: Option<&ml_kem_1024_ciphertext>,
     shared_secret_out: Option<&mut ml_kem_shared_secret>,
 ) -> u8 {
     use fips203::traits::{Decaps, SerDes};
